#!/bin/sh

PKG_ROOT="/var/packages/PetaSpace"
PETASPACE_ETC=${PKG_ROOT}"/etc/"
PETASPACE_DB_DIR=${PETASPACE_ETC}"/clustered_share"
PETASPACE_DB=${PETASPACE_DB_DIR}"/share.db"
PETASPACE_SQL_ROOT=${PKG_ROOT}"/target/sql/"
INIT_SQL=${PETASPACE_SQL_ROOT}"/init_db.sql"
DB_VER='1';
GLUSTER_WORKING_DIRECTORY="/var/lib/glusterd"

init_db()
{
	if [ -f ${PETASPACE_DB} ]; then
		rm ${PETASPACE_DB}
	fi
	if [ -d ${GLUSTER_WORKING_DIRECTORY} ]; then
		rm -r ${GLUSTER_WORKING_DIRECTORY}
	fi
	if [ ! -f ${INIT_SQL} ]; then
		logger -p user.warn -t PetaSpace "Failed to init PetaSpace share.db since ${INIT_SQL} is not existed"
	else
		mkdir ${PETASPACE_DB_DIR}
		sqlite3 ${PETASPACE_DB} < ${INIT_SQL}
		logger -p user.info -t PetaSpace "Init PetaSpace share.db done"
	fi
}

upgrade_db()
{
	while true
	do
		local ver=`sqlite3 ${PETASPACE_DB} "SELECT value FROM db_ver;"`;

		case ${ver} in
			$DB_VER)
				break
				;;
			*)
				logger -p user.warn -t PetaSpace "Failed to upgrade db since bad ver [${ver}]"
				break
				;;
		esac
		logger -p user.warn -t PetaSpace "Upgrade ${PETASPACE_DB} to ver[$(($ver+1))]"
	done
}

repair_db()
{
	if [ ! -f "${PETASPACE_DB}" ]; then
		logger -p user.info -t PetaSpace "    Db not found. Initing db."
		init_db
		return
	else
		local existed=`sqlite3 ${PETASPACE_DB} "SELECT 1 FROM sqlite_master WHERE type='table' AND name='db_ver';"`

		if [ -z "$existed" ]; then
			logger -p user.info -t PetaSpace "    Table not found. Initing db."
			init_db
			return
		else
			local ver=`sqlite3 ${PETASPACE_DB} "SELECT value FROM db_ver;"`;
			if [ -z "$ver" ]; then
				init_db
			else
				upgrade_db
			fi
		fi
	fi
	
}

start()
{
	logger -p user.info -t PetaSpace " ---> Start PetaSpace Check"

	repair_db

	logger -p user.info -t PetaSpace " <--- Finish PetaSpace Check"
}

case "$1" in
start)
	start
;;
*)
	echo "usage: $0 [start]" >&2
	exit 1
;;
esac
